Emmett-REST changelog
=====================

Version 1.5
-----------

*Released on March 19th 2023*

- Update Emmett to 2.5
- Introduce official Python 3.11 support
- Drop Python 3.7 support
- Add support for application modules groups

Version 1.4
-----------

*Released on April 2nd 2022*

- Add OpenAPI schema generation
- Add OpenAPI JSON and YAML schema endpoints
- Add OpenAPI UI endpoint

Version 1.3
-----------

*Released on January 10th 2022*

- Update Emmett to 2.4
- Introduce official Python 3.10 support
- Add `base_path` and `id_path` parameters also to `RESTModule`
- Use `save` and `destroy` methods in relevant endpoints
- Add `use_save` and `use_destroy` parameters to configuration
- Add spatial operators to query language

Version 1.2
-----------

*Released on March 20th 2021*

- Update Emmett to 2.2
- Introduce official Python 3.9 support

Version 1.1
-----------

*Released on December 24th 2020*

- Update Emmett to 2.1

Version 1.0
-----------

*Released on May 3rd 2020*

First public release
